#!/usr/bin/bash
name=mesa
branch=master

if [ ! -d "mesa/mesa-$branch" ]; then
mkdir -p mesa
git clone -b $branch git://anongit.freedesktop.org/git/mesa/mesa mesa/$name-$branch
fi

if [ ! -d "mesa/libdrm" ]; then
git clone git://anongit.freedesktop.org/mesa/drm mesa/libdrm
fi


downloaded="$(echo `find $name-$branch-git-*.tar.xz` | awk -F'-*.tar.xz' '{print $1}' | awk -F"$name-$branch-git-" '{print $NF}')"
downdrm="$(echo `find libdrm-git-*.tar.xz` | awk -F'-*.tar.xz' '{print $1}' | awk -F"libdrm-git-" '{print $NF}')"


pushd  mesa/$name-$branch
git pull origin
onserver="$(git rev-parse --short HEAD)"
gitbranch="$(git rev-parse --abbrev-ref HEAD)"
popd

pushd  mesa/libdrm
git pull
onserverdrm="$(git rev-parse --short HEAD)"
gitdrm="$(git rev-parse --abbrev-ref HEAD)"
popd

echo "version: $(cat mesa/mesa-$branch/VERSION)"
printf "branch: \e[31;4m$gitbranch\e[0m\n"
echo "mesa download: $downloaded"
echo "mesa onserver: $onserver"
echo "libdrm download: $downdrm"
echo "libdrm onserver: $onserverdrm"



# make tarball
if [ "$downloaded" == "$onserver" ] ; then
echo 'tarball mesa is up to date'
else
rm -f $name-$branch-*.tar.xz
cd $name
tar -Jcf ../$name-$branch-git-$onserver.tar.xz --exclude "$name-$branch/.git" $name-$branch
cd ..
fi
echo "file: "$(echo `find $name-$branch-git-*.tar.xz`)""

if [ "$downdrm" == "$onserverdrm" ] ; then
echo 'tarball libdrm is up to date'
else
rm -f libdrm-*.tar.xz
cd $name
tar -Jcf ../libdrm-git-$onserverdrm.tar.xz --exclude "libdrm/.git/objects/pack" libdrm

cd ..
fi
